@@ -74,7 +74,7 @@ class IronicException(Exception):
                 # kwargs doesn't match a variable in the message
                 # log the issue and the kwargs
                 LOG.exception(_LE('Exception in string format operation'))
-                for name, value in kwargs.iteritems():
+                for name, value in kwargs.items():
                     LOG.error("%s: %s" % (name, value))
 
                 if CONF.ironic_lib.fatal_exception_format_errors:
@@ -99,3 +99,7 @@ class InstanceDeployFailure(IronicException):
 class FileSystemNotSupported(IronicException):
     message = _("Failed to create a file system. "
                 "File system %(fs)s is not supported.")
+
+
+class InvalidMetricConfig(IronicException):
+    message = _("Invalid value for metrics config option: %(reason)s")
